==> haskell-transformers-base-0.4.5.2-20-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-transformers-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: transformers-base
version: 0.4.5.2
id: transformers-base-0.4.5.2-1DiUF50wDMZ8pcSXqSIOuW
key: transformers-base-0.4.5.2-1DiUF50wDMZ8pcSXqSIOuW
license: BSD-3-Clause
copyright: 2011 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
           Bas van Dijk <v.dijk.bas@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
        Bas van Dijk <v.dijk.bas@gmail.com>
stability: experimental
homepage: https://github.com/mvv/transformers-base
synopsis: Lift computations from the bottom of a transformer stack
description:
    This package provides a straightforward port of @monadLib@'\''s BaseM
    typeclass to @transformers@.
category: Control
abi: 4a2ae037e0a0da8b04cc50a655f467ad
exposed: True
exposed-modules:
    Control.Monad.Base
import-dirs: /usr/lib/ghc-8.6.1/site-local/transformers-base-0.4.5.2
library-dirs: /usr/lib/ghc-8.6.1/site-local/transformers-base-0.4.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/transformers-base-0.4.5.2
hs-libraries: HStransformers-base-0.4.5.2-1DiUF50wDMZ8pcSXqSIOuW
depends:
    base-4.12.0.0 base-orphans-0.8-8rWfFkGLAVR6Lt3dCtqcr stm-2.5.0.0
    transformers-0.5.5.0
    transformers-compat-0.6.2-JV1ddSnlm3mL2xw4J4K8Kw
haddock-interfaces: /usr/share/doc/haskell-transformers-base/html/transformers-base.haddock
haddock-html: /usr/share/doc/haskell-transformers-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-transformers-base-0.4.5.2-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-transformers-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: transformers-base
version: 0.4.5.2
id: transformers-base-0.4.5.2-GVqlM7MFCpoHJlEFRaTwrG
key: transformers-base-0.4.5.2-GVqlM7MFCpoHJlEFRaTwrG
license: BSD-3-Clause
copyright: 2011 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
           Bas van Dijk <v.dijk.bas@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
        Bas van Dijk <v.dijk.bas@gmail.com>
stability: experimental
homepage: https://github.com/mvv/transformers-base
synopsis: Lift computations from the bottom of a transformer stack
description:
    This package provides a straightforward port of @monadLib@'\''s BaseM
    typeclass to @transformers@.
category: Control
abi: 88499f9daf9d52c5f8374ab6a5fb4efb
exposed: True
exposed-modules:
    Control.Monad.Base
import-dirs: /usr/lib/ghc-8.6.3/site-local/transformers-base-0.4.5.2
library-dirs: /usr/lib/ghc-8.6.3/site-local/transformers-base-0.4.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/transformers-base-0.4.5.2
hs-libraries: HStransformers-base-0.4.5.2-GVqlM7MFCpoHJlEFRaTwrG
depends:
    base-4.12.0.0 base-orphans-0.8-HC8rxCgWXMG2ghd5IcEIzb stm-2.5.0.0
    transformers-0.5.5.0
    transformers-compat-0.6.2-JV1ddSnlm3mL2xw4J4K8Kw
haddock-interfaces: /usr/share/doc/haskell-transformers-base/html/transformers-base.haddock
haddock-html: /usr/share/doc/haskell-transformers-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
